@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2016 Red Hat, Inc.
+ * Copyright © 2012 – 2017 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -34,9 +34,10 @@ G_BEGIN_DECLS
 #define PHOTOS_TYPE_APPLICATION (photos_application_get_type ())
 G_DECLARE_FINAL_TYPE (PhotosApplication, photos_application, PHOTOS, APPLICATION, GtkApplication);
 
-GtkApplication        *photos_application_new                    (void);
+GApplication          *photos_application_new                    (void);
 
-GomMiner              *photos_application_get_miner              (PhotosApplication *self, const gchar *provider_type);
+GomMiner              *photos_application_get_miner              (PhotosApplication *self,
+                                                                  const gchar *provider_type);
 
 GList                 *photos_application_get_miners_running     (PhotosApplication *self);
 
