@@ -25,7 +25,6 @@
 
 #include <babl/babl.h>
 #include <gegl.h>
-#include <gegl-plugin.h>
 #include <jpeglib.h>
 
 #include "photos-jpeg-count.h"
@@ -42,11 +41,6 @@ struct _PhotosOperationJpgGuessSizes
   gsize sizes[2];
 };
 
-struct _PhotosOperationJpgGuessSizesClass
-{
-  GeglOperationSinkClass parent_class;
-};
-
 enum
 {
   PROP_0,
