@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2016 Red Hat, Inc.
+ * Copyright © 2012 – 2017 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -41,11 +41,6 @@ struct _PhotosTrackerOverviewController
   PhotosOffsetController *offset_cntrlr;
 };
 
-struct _PhotosTrackerOverviewControllerClass
-{
-  PhotosTrackerControllerClass parent_class;
-};
-
 
 G_DEFINE_TYPE_WITH_CODE (PhotosTrackerOverviewController,
                          photos_tracker_overview_controller,
