@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2016 Red Hat, Inc.
+ * Copyright © 2012 – 2017 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,19 +30,11 @@
 G_BEGIN_DECLS
 
 #define PHOTOS_TYPE_TRACKER_OVERVIEW_CONTROLLER (photos_tracker_overview_controller_get_type ())
-
-#define PHOTOS_TRACKER_OVERVIEW_CONTROLLER(obj) \
-  (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
-   PHOTOS_TYPE_TRACKER_OVERVIEW_CONTROLLER, PhotosTrackerOverviewController))
-
-#define PHOTOS_IS_TRACKER_OVERVIEW_CONTROLLER(obj) \
-  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
-   PHOTOS_TYPE_TRACKER_OVERVIEW_CONTROLLER))
-
-typedef struct _PhotosTrackerOverviewController      PhotosTrackerOverviewController;
-typedef struct _PhotosTrackerOverviewControllerClass PhotosTrackerOverviewControllerClass;
-
-GType                     photos_tracker_overview_controller_get_type          (void) G_GNUC_CONST;
+G_DECLARE_FINAL_TYPE (PhotosTrackerOverviewController,
+                      photos_tracker_overview_controller,
+                      PHOTOS,
+                      TRACKER_OVERVIEW_CONTROLLER,
+                      PhotosTrackerController);
 
 PhotosTrackerController  *photos_tracker_overview_controller_dup_singleton     (void);
 
