@@ -418,9 +418,6 @@ photos_utils_get_thumbnail_icon (const gchar *uri)
     }
 
   thumb_path = g_file_info_get_attribute_byte_string (info, G_FILE_ATTRIBUTE_THUMBNAIL_PATH);
-  if (thumb_path == NULL)
-    goto out;
-
   thumb_file = g_file_new_for_path (thumb_path);
   icon = g_file_icon_new (thumb_file);
 
@@ -1078,6 +1075,27 @@ photos_utils_get_provider_name (PhotosBaseManager *src_mngr, PhotosBaseItem *ite
 }
 
 
+gboolean
+photos_utils_get_selection_mode (void)
+{
+  GAction *action;
+  GApplication *app;
+  GVariant *state;
+  gboolean selection_mode;
+
+  app = g_application_get_default ();
+  action = g_action_map_lookup_action (G_ACTION_MAP (app), "selection-mode");
+
+  state = g_action_get_state (action);
+  g_return_val_if_fail (state != NULL, FALSE);
+
+  selection_mode = g_variant_get_boolean (state);
+
+  g_variant_unref (state);
+  return selection_mode;
+}
+
+
 gchar *
 photos_utils_get_thumbnail_path_for_file (GFile *file)
 {
@@ -1199,6 +1217,75 @@ photos_utils_object_list_free_full (GList *objects)
 }
 
 
+static gboolean
+photos_utils_adjustment_can_scroll (GtkAdjustment *adjustment)
+{
+  gdouble lower;
+  gdouble page_size;
+  gdouble upper;
+
+  g_return_val_if_fail (GTK_IS_ADJUSTMENT (adjustment), FALSE);
+
+  lower = gtk_adjustment_get_lower (adjustment);
+  page_size = gtk_adjustment_get_page_size (adjustment);
+  upper = gtk_adjustment_get_upper (adjustment);
+
+  return upper - lower > page_size;
+}
+
+
+gboolean
+photos_utils_scrolled_window_can_scroll (GtkScrolledWindow *scrolled_window)
+{
+  GtkAdjustment *adjustment;
+  gboolean ret_val = TRUE;
+
+  g_return_val_if_fail (GTK_IS_SCROLLED_WINDOW (scrolled_window), FALSE);
+
+  adjustment = gtk_scrolled_window_get_hadjustment (scrolled_window);
+  if (photos_utils_adjustment_can_scroll (adjustment))
+    goto out;
+
+  adjustment = gtk_scrolled_window_get_vadjustment (scrolled_window);
+  if (photos_utils_adjustment_can_scroll (adjustment))
+    goto out;
+
+  ret_val = FALSE;
+
+ out:
+  return ret_val;
+}
+
+
+static void
+photos_utils_adjustment_scroll (GtkAdjustment *adjustment, gdouble delta)
+{
+  gdouble value;
+
+  g_return_if_fail (GTK_IS_ADJUSTMENT (adjustment));
+
+  value = gtk_adjustment_get_value (adjustment);
+  value += delta;
+  gtk_adjustment_set_value (adjustment, value);
+}
+
+
+void
+photos_utils_scrolled_window_scroll (GtkScrolledWindow *scrolled_window, gdouble delta_x, gdouble delta_y)
+{
+  GtkAdjustment *adjustment;
+
+  g_return_if_fail (GTK_IS_SCROLLED_WINDOW (scrolled_window));
+  g_return_if_fail (photos_utils_scrolled_window_can_scroll (scrolled_window));
+
+  adjustment = gtk_scrolled_window_get_hadjustment (scrolled_window);
+  photos_utils_adjustment_scroll (adjustment, delta_x);
+
+  adjustment = gtk_scrolled_window_get_vadjustment (scrolled_window);
+  photos_utils_adjustment_scroll (adjustment, delta_y);
+}
+
+
 static void
 photos_utils_update_executed (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
