@@ -141,6 +141,8 @@ char*            photos_utils_get_pixbuf_common_suffix    (GdkPixbufFormat *form
 
 const gchar     *photos_utils_get_provider_name           (PhotosBaseManager *src_mngr, PhotosBaseItem *item);
 
+gboolean         photos_utils_get_selection_mode          (void);
+
 gchar           *photos_utils_get_thumbnail_path_for_file (GFile *file);
 
 gchar           *photos_utils_get_thumbnail_path_for_uri  (const gchar *uri);
@@ -157,6 +159,12 @@ void             photos_utils_list_box_header_func        (GtkListBoxRow *row,
 
 void             photos_utils_object_list_free_full       (GList *objects);
 
+gboolean         photos_utils_scrolled_window_can_scroll  (GtkScrolledWindow *scrolled_window);
+
+void             photos_utils_scrolled_window_scroll      (GtkScrolledWindow *scrolled_window,
+                                                           gdouble delta_x,
+                                                           gdouble delta_y);
+
 void             photos_utils_set_edited_name             (const gchar *urn, const gchar *title);
 
 void             photos_utils_set_favorite                (const gchar *urn, gboolean is_favorite);
